@@ -18,7 +18,7 @@
 
 /* $Id$ */
 
-#define CONFIGURE_COMMAND " './configure'  '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--disable-posix' '--disable-opcache' '--disable-pdo' '--disable-json' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--with-libxml-dir=/usr/pkg' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=x86_64--netbsd' '--host=x86_64--netbsd' '--mandir=/usr/pkg/man' 'build_alias=x86_64--netbsd' 'host_alias=x86_64--netbsd' 'LIBS=' 'CXXCPP=cpp'"
+#define CONFIGURE_COMMAND " './configure'  '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--disable-posix' '--disable-opcache' '--disable-pdo' '--disable-json' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--with-libxml-dir=/usr/pkg' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--without-pcre-jit' '--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' '--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' 'build_alias=armv6--netbsdelf-eabihf' 'host_alias=armv6--netbsdelf-eabihf' 'LIBS=' 'CXXCPP=cpp'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
